@@ -1041,13 +1041,15 @@ weechat_python_eval (struct t_gui_buffer *buffer, int send_to_buffer_as_input,
                      int exec_commands, const char *code)
 {
     void *func_argv[1], *result;
+    int old_python_quiet;
 
     if (!python_script_eval)
     {
+        old_python_quiet = python_quiet;
         python_quiet = 1;
         python_script_eval = weechat_python_load (WEECHAT_SCRIPT_EVAL_NAME,
                                                   PYTHON_EVAL_SCRIPT);
-        python_quiet = 0;
+        python_quiet = old_python_quiet;
         if (!python_script_eval)
             return 0;
     }
@@ -1076,15 +1078,33 @@ weechat_python_eval (struct t_gui_buffer *buffer, int send_to_buffer_as_input,
 
     if (!weechat_config_boolean (python_config_look_eval_keep_context))
     {
+        old_python_quiet = python_quiet;
         python_quiet = 1;
         weechat_python_unload (python_script_eval);
-        python_quiet = 0;
+        python_quiet = old_python_quiet;
         python_script_eval = NULL;
     }
 
     return 1;
 }
 
+/*
+ * Function called before the auto-load of scripts.
+ */
+
+void
+weechat_python_init_before_autoload ()
+{
+#if PY_VERSION_HEX >= 0x030C0000 && PY_VERSION_HEX < 0x030D0000
+    /*
+     * Workaround for crash when ending interpreters in Python 3.12:
+     * the first time we load a script, we eval an empty string.
+     * See https://github.com/weechat/weechat/issues/2046
+     */
+    weechat_python_eval (NULL, 0, 0, "");
+#endif
+}
+
 /*
  * Callback for command "/python".
  */
@@ -1095,7 +1115,7 @@ weechat_python_command_cb (const void *pointer, void *data,
                            int argc, char **argv, char **argv_eol)
 {
     char *ptr_name, *ptr_code, *path_script;
-    int i, send_to_buffer_as_input, exec_commands;
+    int i, send_to_buffer_as_input, exec_commands, old_python_quiet;
 
     /* make C compiler happy */
     (void) pointer;
@@ -1154,6 +1174,7 @@ weechat_python_command_cb (const void *pointer, void *data,
                  || (weechat_strcmp (argv[1], "reload") == 0)
                  || (weechat_strcmp (argv[1], "unload") == 0))
         {
+            old_python_quiet = python_quiet;
             ptr_name = argv_eol[2];
             if (strncmp (ptr_name, "-q ", 3) == 0)
             {
@@ -1183,7 +1204,7 @@ weechat_python_command_cb (const void *pointer, void *data,
                 /* unload python script */
                 weechat_python_unload_name (ptr_name);
             }
-            python_quiet = 0;
+            python_quiet = old_python_quiet;
         }
         else if (weechat_strcmp (argv[1], "eval") == 0)
         {
@@ -1513,6 +1534,8 @@ weechat_python_signal_script_action_cb (const void *pointer, void *data,
 int
 weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 {
+    int old_python_quiet;
+
     /* make C compiler happy */
     (void) argc;
     (void) argv;
@@ -1586,11 +1609,13 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     python_data.callback_signal_debug_dump = &weechat_python_signal_debug_dump_cb;
     python_data.callback_signal_script_action = &weechat_python_signal_script_action_cb;
     python_data.callback_load_file = &weechat_python_load_cb;
+    python_data.init_before_autoload = &weechat_python_init_before_autoload;
     python_data.unload_all = &weechat_python_unload_all;
 
+    old_python_quiet = python_quiet;
     python_quiet = 1;
     plugin_script_init (weechat_python_plugin, &python_data);
-    python_quiet = 0;
+    python_quiet = old_python_quiet;
 
     plugin_script_display_short_list (weechat_python_plugin,
                                       python_scripts);
@@ -1617,15 +1642,18 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 int
 weechat_plugin_end (struct t_weechat_plugin *plugin)
 {
+    int old_python_quiet;
+
     /* unload all scripts */
+    old_python_quiet = python_quiet;
     python_quiet = 1;
+    plugin_script_end (plugin, &python_data);
     if (python_script_eval)
     {
         weechat_python_unload (python_script_eval);
         python_script_eval = NULL;
     }
-    plugin_script_end (plugin, &python_data);
-    python_quiet = 0;
+    python_quiet = old_python_quiet;
 
     /* free python interpreter */
     if (python_mainThreadState != NULL)
