@@ -170,7 +170,9 @@ relay_weechat_protocol_handshake_reply (struct t_relay_client *client,
             "password_hash_algo",
             (client->password_hash_algo >= 0) ?
             relay_auth_password_hash_algo_name[client->password_hash_algo] : "");
-        snprintf (string, sizeof (string), "%d", client->password_hash_iterations);
+        snprintf (string, sizeof (string),
+                  "%d",
+                  weechat_config_integer (relay_config_network_password_hash_iterations));
         weechat_hashtable_set (
             hashtable,
             "password_hash_iterations",
@@ -206,8 +208,7 @@ relay_weechat_protocol_handshake_reply (struct t_relay_client *client,
         weechat_hashtable_free (hashtable);
     }
 
-    if (totp_secret)
-        free (totp_secret);
+    free (totp_secret);
 }
 
 
@@ -223,7 +224,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(handshake)
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(0);
 
-    if (client->status != RELAY_STATUS_WAITING_AUTH)
+    if (client->status != RELAY_STATUS_AUTHENTICATING)
         return WEECHAT_RC_OK;
 
     /* only one handshake is allowed */
@@ -388,13 +389,16 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
                 if (strcmp (options[i], "password") == 0)
                 {
                     password_received = 1;
-                    if (relay_auth_password (client, pos, relay_password))
+                    if ((client->password_hash_algo == RELAY_AUTH_PASSWORD_HASH_PLAIN)
+                        && (relay_auth_check_password_plain (client, pos, relay_password) == 0))
+                    {
                         RELAY_WEECHAT_DATA(client, password_ok) = 1;
+                    }
                 }
                 else if (strcmp (options[i], "password_hash") == 0)
                 {
                     password_received = 1;
-                    if (relay_auth_password_hash (client, pos, relay_password))
+                    if (relay_auth_password_hash (client, pos, relay_password) == 0)
                         RELAY_WEECHAT_DATA(client, password_ok) = 1;
                 }
                 else if (strcmp (options[i], "totp") == 0)
@@ -415,8 +419,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
                             info_totp = weechat_info_get ("totp_validate", info_totp_args);
                             if (info_totp && (strcmp (info_totp, "1") == 0))
                                 RELAY_WEECHAT_DATA(client, totp_ok) = 1;
-                            if (info_totp)
-                                free (info_totp);
+                            free (info_totp);
                             free (info_totp_args);
                         }
                     }
@@ -446,10 +449,8 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
         relay_client_set_status (client, RELAY_STATUS_AUTH_FAILED);
     }
 
-    if (relay_password)
-        free (relay_password);
-    if (totp_secret)
-        free (totp_secret);
+    free (relay_password);
+    free (totp_secret);
 
     return WEECHAT_RC_OK;
 }
@@ -458,7 +459,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
  * Callback for command "hdata" (from client).
  *
  * Message looks like:
- *   hdata buffer:gui_buffers(*) number,name,type,nicklist,title
+ *   hdata buffer:gui_buffers(*) id,number,name,type,nicklist,title
  *   hdata buffer:gui_buffers(*)/own_lines/first_line(*)/data date,displayed,prefix,message
  */
 
@@ -510,8 +511,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(info)
         relay_weechat_msg_add_string (msg, info);
         relay_weechat_msg_send (client, msg);
         relay_weechat_msg_free (msg);
-        if (info)
-            free (info);
+        free (info);
     }
 
     return WEECHAT_RC_OK;
@@ -612,7 +612,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(input)
 {
     struct t_gui_buffer *ptr_buffer;
     struct t_hashtable *options;
-    const char *ptr_weechat_commands;
+    const char *ptr_commands;
     char *pos;
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(1);
@@ -648,15 +648,9 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(input)
         return WEECHAT_RC_OK;
     }
 
-    ptr_weechat_commands = weechat_config_string (
-        relay_config_weechat_commands);
-    if (ptr_weechat_commands && ptr_weechat_commands[0])
-    {
-        weechat_hashtable_set (
-            options,
-            "commands",
-            weechat_config_string (relay_config_weechat_commands));
-    }
+    ptr_commands = weechat_config_string (relay_config_network_commands);
+    if (ptr_commands && ptr_commands[0])
+        weechat_hashtable_set (options, "commands", ptr_commands);
 
     /*
      * delay the execution of command after we go back in the WeeChat
@@ -817,8 +811,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(completion)
     return WEECHAT_RC_OK;
 
 error:
-    if (completion)
-        weechat_completion_free (completion);
+    weechat_completion_free (completion);
 
     msg = relay_weechat_msg_new (id);
     if (msg)
@@ -882,7 +875,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,short_name,"
+                                             "id,number,full_name,short_name,"
                                              "nicklist,title,local_variables,"
                                              "prev_buffer,next_buffer");
                 relay_weechat_msg_send (ptr_client, msg);
@@ -907,7 +900,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,type");
+                                             "id,number,full_name,type");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
             }
@@ -930,7 +923,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,"
+                                             "id,number,full_name,"
                                              "prev_buffer,next_buffer");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
@@ -955,7 +948,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,"
+                                             "id,number,full_name,"
                                              "prev_buffer,next_buffer");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
@@ -980,7 +973,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,"
+                                             "id,number,full_name,"
                                              "prev_buffer,next_buffer");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
@@ -1025,7 +1018,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,short_name,"
+                                             "id,number,full_name,short_name,"
                                              "local_variables");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
@@ -1049,7 +1042,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,title");
+                                             "id,number,full_name,title");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
             }
@@ -1072,7 +1065,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name,local_variables");
+                                             "id,number,full_name,local_variables");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
             }
@@ -1094,7 +1087,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name");
+                                             "id,number,full_name");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
             }
@@ -1152,7 +1145,7 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                 snprintf (cmd_hdata, sizeof (cmd_hdata),
                           "buffer:0x%lx", (unsigned long)ptr_buffer);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
-                                             "number,full_name");
+                                             "id,number,full_name");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
             }
@@ -1735,7 +1728,7 @@ relay_weechat_protocol_recv (struct t_relay_client *client, const char *data)
           { NULL, NULL }
         };
 
-    if (!data || !data[0] || RELAY_CLIENT_HAS_ENDED(client))
+    if (!data || !data[0] || RELAY_STATUS_HAS_ENDED(client->status))
         return;
 
     /* display debug message */
@@ -1852,13 +1845,9 @@ relay_weechat_protocol_recv (struct t_relay_client *client, const char *data)
     }
 
 end:
-    if (data_unescaped)
-        free (data_unescaped);
-    if (id)
-        free (id);
+    free (data_unescaped);
+    free (id);
     free (command);
-    if (argv)
-        weechat_string_free_split (argv);
-    if (argv_eol)
-        weechat_string_free_split (argv_eol);
+    weechat_string_free_split (argv);
+    weechat_string_free_split (argv_eol);
 }
