@@ -26,13 +26,14 @@ extern "C"
 #include <stdio.h>
 #include <string.h>
 #include <regex.h>
-#include "src/core/wee-eval.h"
-#include "src/core/wee-config.h"
-#include "src/core/wee-config-file.h"
-#include "src/core/wee-hashtable.h"
-#include "src/core/wee-secure.h"
-#include "src/core/wee-string.h"
-#include "src/core/wee-version.h"
+#include <time.h>
+#include "src/core/core-eval.h"
+#include "src/core/core-config.h"
+#include "src/core/core-config-file.h"
+#include "src/core/core-hashtable.h"
+#include "src/core/core-secure.h"
+#include "src/core/core-string.h"
+#include "src/core/core-version.h"
 #include "src/gui/gui-buffer.h"
 #include "src/gui/gui-line.h"
 #include "src/gui/gui-color.h"
@@ -453,8 +454,10 @@ TEST(CoreEval, EvalExpression)
 {
     struct t_hashtable *pointers, *extra_vars, *options;
     struct t_config_option *ptr_option;
-    char *value, str_value[256], str_expr[256];
+    char *value, str_value[256], str_expr[256], *error;
     const char *ptr_debug_output;
+    long number;
+    time_t time_now;
 
     pointers = hashtable_new (32,
                               WEECHAT_HASHTABLE_STRING,
@@ -898,6 +901,13 @@ TEST(CoreEval, EvalExpression)
                              pointers, extra_vars, options);
     LONGS_EQUAL(8, strlen (value));
     free (value);
+    value = eval_expression ("${date:%!}", pointers, extra_vars, options);
+    CHECK(value);
+    error = NULL;
+    number = strtol (value, &error, 10);
+    CHECK(error && !error[0]);
+    time_now = time (NULL);
+    CHECK((number >= time_now - 10) && (number <= time_now + 10));
 
     /* test ternary operator */
     WEE_CHECK_EVAL("1", "${if:5>2}");
@@ -1004,9 +1014,11 @@ TEST(CoreEval, EvalExpression)
     WEE_CHECK_EVAL("", "${buffer[unknown_list].full_name}");
     WEE_CHECK_EVAL("", "${unknown_pointer}");
     WEE_CHECK_EVAL("", "${my_null_pointer}");
-    snprintf (str_value, sizeof (str_value),
-              "0x%lx", (long unsigned int)gui_buffers);
+    snprintf (str_value, sizeof (str_value), "%p", gui_buffers);
     WEE_CHECK_EVAL(str_value, "${my_buffer_pointer}");
+    WEE_CHECK_EVAL(str_value, "${buffer}");
+    WEE_CHECK_EVAL("0x0", "${buffer.prev_buffer}");
+    WEE_CHECK_EVAL("0x0", "${buffer.next_buffer}");
     WEE_CHECK_EVAL("0x1234abcd", "${my_other_pointer}");
     WEE_CHECK_EVAL("", "${buffer[unknown_pointer].full_name}");
     WEE_CHECK_EVAL("", "${buffer[my_null_pointer].full_name}");
@@ -1014,7 +1026,7 @@ TEST(CoreEval, EvalExpression)
     WEE_CHECK_EVAL("", "${buffer[my_other_pointer].full_name}");
     WEE_CHECK_EVAL("core.weechat", "${buffer[gui_buffers].full_name}");
     snprintf (str_value, sizeof (str_value),
-              "${buffer[0x%lx].full_name}", (long unsigned int)gui_buffers);
+              "${buffer[%p].full_name}", gui_buffers);
     WEE_CHECK_EVAL("core.weechat", str_value);
     snprintf (str_value, sizeof (str_value), "%c", 1);
     WEE_CHECK_EVAL(str_value,
@@ -1026,7 +1038,7 @@ TEST(CoreEval, EvalExpression)
     WEE_CHECK_EVAL(str_value,
                    "${window.buffer.own_lines.first_line.data.date}");
     snprintf (str_value, sizeof (str_value),
-              "0x%lx", (long unsigned int)(gui_buffers->local_variables));
+              "%p", gui_buffers->local_variables);
     WEE_CHECK_EVAL(str_value, "${window.buffer.local_variables}");
     WEE_CHECK_EVAL("core", "${window.buffer.local_variables.plugin}");
     WEE_CHECK_EVAL("weechat", "${window.buffer.local_variables.name}");
