@@ -1,5 +1,5 @@
 /*
- * test-relay-irc.cpp - test IRC protocol for relay to client
+ * test-relay-irc.cpp - test relay IRC protocol
  *
  * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
@@ -22,17 +22,16 @@
 #include "CppUTest/TestHarness.h"
 
 #include "tests/tests.h"
-#include "tests/tests-record.h"
 
 extern "C"
 {
 #include <stdio.h>
 #include <string.h>
-#include "src/core/wee-arraylist.h"
-#include "src/core/wee-config-file.h"
-#include "src/core/wee-hashtable.h"
-#include "src/core/wee-hook.h"
-#include "src/core/wee-string.h"
+#include "src/core/core-arraylist.h"
+#include "src/core/core-config-file.h"
+#include "src/core/core-hashtable.h"
+#include "src/core/core-hook.h"
+#include "src/core/core-string.h"
 #include "src/plugins/plugin.h"
 #include "src/plugins/irc/irc-server.h"
 #include "src/plugins/relay/relay.h"
@@ -138,26 +137,18 @@ TEST_GROUP(RelayIrcWithClient)
 
     void test_client_recv (const char *data)
     {
-        record_start ();
-
         arraylist_clear (sent_messages_client);
         arraylist_clear (sent_messages_irc);
 
         relay_irc_recv (ptr_relay_client, data);
-
-        record_stop ();
     }
 
     void test_client_send (const char *data)
     {
-        record_start ();
-
         arraylist_clear (sent_messages_client);
         arraylist_clear (sent_messages_irc);
 
         relay_irc_sendf (ptr_relay_client, "%s", data);
-
-        record_stop ();
     }
 
     char **test_build_error (const char *msg1,
@@ -325,19 +316,19 @@ TEST_GROUP(RelayIrcWithClient)
                        "/server fakerecv "
                        "\":server 001 alice :Welcome on this server, nick1!\"");
 
-        /* create a fake server (no I/O) */
+        /* create a relay server */
         ptr_relay_server = relay_server_new (
             "irc.test",
             RELAY_PROTOCOL_IRC,
             "test",
-            9000,
+            9001,
             NULL,  /* path */
             1,  /* ipv4 */
             0,  /* ipv6 */
             0,  /* tls */
             0);  /* unix_socket */
 
-        /* create a fake client (no I/O) */
+        /* create a fake relay client (no I/O) */
         ptr_relay_client = relay_client_new (-1, "test", ptr_relay_server);
     }
 
